#include <iostream>
#include <unordered_set>
#include <bitset>
#include <vector>
#include <queue>

#define MAX_STOP_COUNT 1000000

static bool contains(std::unordered_set<int> const& s, int x) {
	return s.find(x) != s.end();
}

struct bus_stop {
	std::unordered_set<int> connections;
};

static std::vector<bus_stop> bus_stops;

void init(int stop_count, std::vector<std::pair<int, int>> routes) {
	bus_stops.resize(stop_count);
	for (auto [u, v] : routes) {
        u--;
        v--;
		bus_stops[u].connections.insert(v);
		bus_stops[v].connections.insert(u);
	}
}

void close(int u, int v) {
    u--;
    v--;
	bus_stops[u].connections.erase(v);
	bus_stops[v].connections.erase(u);
}

using visited_set = std::bitset<MAX_STOP_COUNT>;

/*static bool q(visited_set& visited, int begin, int end) {
	if (begin == end)
		return true;
	visited[begin] = true;
	for (int next : bus_stops[begin].connections)
		if (!visited[next])
			if (q(visited, next, end))
				return true;
	return false;
}*/

bool question(int begin, int end) {
    if (begin == end)
        return true;
    begin--;
    end--;
	visited_set visited;
	//return q(visited, begin, end);
	std::queue<int> q;
	q.push(begin);
	while (!q.empty()) {
        int x = q.front();
        q.pop();
        visited[x] = true;
        for (int next : bus_stops[x].connections)
            if (!visited[next]) {
                if (next == end)
                    return true;
                q.push(next);
            }
	}
	return false;
}